=== modified file 'drizzled/common_includes.h'
--- drizzled/common_includes.h	2008-10-30 19:22:40 +0000
+++ drizzled/common_includes.h	2008-10-30 19:42:06 +0000
@@ -73,7 +73,6 @@
 #define current_session _current_session()
 
 
-#include <drizzled/handler.h>
 #include <drizzled/table_list.h>
 /* Drizzle server data type class definitions */
 #include <drizzled/field.h>

=== modified file 'drizzled/definitions.h'
--- drizzled/definitions.h	2008-10-29 21:21:57 +0000
+++ drizzled/definitions.h	2008-10-30 19:42:06 +0000
@@ -492,4 +492,380 @@
 #define SLAVE_IO  1
 #define SLAVE_SQL 2
 
+#ifndef NO_HASH
+#define NO_HASH				/* Not yet implemented */
+#endif
+
+// the following is for checking tables
+
+#define HA_ADMIN_ALREADY_DONE	  1
+#define HA_ADMIN_OK               0
+#define HA_ADMIN_NOT_IMPLEMENTED -1
+#define HA_ADMIN_FAILED		 -2
+#define HA_ADMIN_CORRUPT         -3
+#define HA_ADMIN_INTERNAL_ERROR  -4
+#define HA_ADMIN_INVALID         -5
+#define HA_ADMIN_REJECT          -6
+#define HA_ADMIN_TRY_ALTER       -7
+#define HA_ADMIN_WRONG_CHECKSUM  -8
+#define HA_ADMIN_NOT_BASE_TABLE  -9
+#define HA_ADMIN_NEEDS_UPGRADE  -10
+#define HA_ADMIN_NEEDS_ALTER    -11
+#define HA_ADMIN_NEEDS_CHECK    -12
+
+
+#define HA_ADD_INDEX                  (0)
+#define HA_DROP_INDEX                 (1)
+#define HA_ALTER_INDEX                (2)
+#define HA_RENAME_INDEX               (3)
+#define HA_ADD_UNIQUE_INDEX           (4)
+#define HA_DROP_UNIQUE_INDEX          (5)
+#define HA_ALTER_UNIQUE_INDEX         (6)
+#define HA_RENAME_UNIQUE_INDEX        (7)
+#define HA_ADD_PK_INDEX               (8)
+#define HA_DROP_PK_INDEX              (9)
+#define HA_ALTER_PK_INDEX             (10)
+#define HA_ADD_COLUMN                 (11)
+#define HA_DROP_COLUMN                (12)
+#define HA_CHANGE_COLUMN              (13)
+#define HA_ALTER_COLUMN_NAME          (14)
+#define HA_ALTER_COLUMN_TYPE          (15)
+#define HA_ALTER_COLUMN_ORDER         (16)
+#define HA_ALTER_COLUMN_NULLABLE      (17)
+#define HA_COLUMN_DEFAULT_VALUE       (18)
+#define HA_COLUMN_STORAGE             (19)
+#define HA_COLUMN_FORMAT              (20)
+#define HA_ADD_FOREIGN_KEY            (21)
+#define HA_DROP_FOREIGN_KEY           (22)
+#define HA_ALTER_FOREIGN_KEY          (23)
+#define HA_ADD_CONSTRAINT             (24)
+#define HA_CHANGE_CHARACTER_SET       (30)
+#define HA_SET_DEFAULT_CHARACTER_SET  (31)
+#define HA_CHANGE_AUTOINCREMENT_VALUE (32)
+#define HA_ALTER_STORAGE              (33)
+#define HA_ALTER_TABLESPACE           (34)
+#define HA_ALTER_ROW_FORMAT           (35)
+#define HA_RENAME_TABLE               (36)
+#define HA_ALTER_STORAGE_ENGINE       (37)
+#define HA_RECREATE                   (38)
+#define HA_ALTER_STORED_VCOL          (39)
+/* Remember to increase HA_MAX_ALTER_FLAGS when adding more flags! */
+
+/* Return values for check_if_supported_alter */
+
+#define HA_ALTER_ERROR               -1
+#define HA_ALTER_SUPPORTED_WAIT_LOCK  0
+#define HA_ALTER_SUPPORTED_NO_LOCK    1
+#define HA_ALTER_NOT_SUPPORTED        2
+
+/* Bits in table_flags() to show what database can do */
+
+#define HA_NO_TRANSACTIONS     (1 << 0) /* Doesn't support transactions */
+#define HA_PARTIAL_COLUMN_READ (1 << 1) /* read may not return all columns */
+#define HA_TABLE_SCAN_ON_INDEX (1 << 2) /* No separate data/index file */
+/*
+  The following should be set if the following is not true when scanning
+  a table with rnd_next()
+  - We will see all rows (including deleted ones)
+  - Row positions are 'table->s->db_record_offset' apart
+  If this flag is not set, filesort will do a postion() call for each matched
+  row to be able to find the row later.
+*/
+#define HA_REC_NOT_IN_SEQ      (1 << 3)
+
+/*
+  Reading keys in random order is as fast as reading keys in sort order
+  (Used in records.cc to decide if we should use a record cache and by
+  filesort to decide if we should sort key + data or key + pointer-to-row
+*/
+#define HA_FAST_KEY_READ       (1 << 5)
+/*
+  Set the following flag if we on delete should force all key to be read
+  and on update read all keys that changes
+*/
+#define HA_REQUIRES_KEY_COLUMNS_FOR_DELETE (1 << 6)
+#define HA_NULL_IN_KEY         (1 << 7) /* One can have keys with NULL */
+#define HA_DUPLICATE_POS       (1 << 8)    /* ha_position() gives dup row */
+#define HA_NO_BLOBS            (1 << 9) /* Doesn't support blobs */
+#define HA_CAN_INDEX_BLOBS     (1 << 10)
+#define HA_AUTO_PART_KEY       (1 << 11) /* auto-increment in multi-part key */
+#define HA_REQUIRE_PRIMARY_KEY (1 << 12) /* .. and can't create a hidden one */
+#define HA_STATS_RECORDS_IS_EXACT (1 << 13) /* stats.records is exact */
+/*
+  If we get the primary key columns for free when we do an index read
+  It also implies that we have to retrive the primary key when using
+  position() and rnd_pos().
+*/
+#define HA_PRIMARY_KEY_IN_READ_INDEX (1 << 15)
+/*
+  If HA_PRIMARY_KEY_REQUIRED_FOR_POSITION is set, it means that to position()
+  uses a primary key. Without primary key, we can't call position().
+*/ 
+#define HA_PRIMARY_KEY_REQUIRED_FOR_POSITION (1 << 16) 
+#define HA_NOT_DELETE_WITH_CACHE (1 << 18)
+/*
+  The following is we need to a primary key to delete (and update) a row.
+  If there is no primary key, all columns needs to be read on update and delete
+*/
+#define HA_PRIMARY_KEY_REQUIRED_FOR_DELETE (1 << 19)
+#define HA_NO_PREFIX_CHAR_KEYS (1 << 20)
+#define HA_NO_AUTO_INCREMENT   (1 << 23)
+#define HA_HAS_CHECKSUM        (1 << 24)
+/* Table data are stored in separate files (for lower_case_table_names) */
+#define HA_FILE_BASED	       (1 << 26)
+#define HA_NEED_READ_RANGE_BUFFER (1 << 29) /* for read_multi_range */
+#define HA_ANY_INDEX_MAY_BE_UNIQUE (1 << 30)
+#define HA_NO_COPY_ON_ALTER    (INT64_C(1) << 31)
+#define HA_HAS_RECORDS	       (INT64_C(1) << 32) /* records() gives exact count*/
+#define HA_MRR_CANT_SORT       (INT64_C(1) << 34)
+
+/*
+  Engine is capable of row-format and statement-format logging,
+  respectively
+*/
+#define HA_BINLOG_ROW_CAPABLE  (INT64_C(1) << 35)
+#define HA_BINLOG_STMT_CAPABLE (INT64_C(1) << 36)
+
+#define HA_ONLINE_ALTER        (INT64_C(1) << 37)
+
+/*
+  Set of all binlog flags. Currently only contain the capabilities
+  flags.
+ */
+#define HA_BINLOG_FLAGS (HA_BINLOG_ROW_CAPABLE | HA_BINLOG_STMT_CAPABLE)
+
+/* bits in index_flags(index_number) for what you can do with index */
+#define HA_READ_NEXT            1       /* TODO really use this flag */
+#define HA_READ_PREV            2       /* supports ::index_prev */
+#define HA_READ_ORDER           4       /* index_next/prev follow sort order */
+#define HA_READ_RANGE           8       /* can find all records in a range */
+#define HA_ONLY_WHOLE_INDEX	16	/* Can't use part key searches */
+#define HA_KEYREAD_ONLY         64	/* Support HA_EXTRA_KEYREAD */
+/*
+  Index scan will not return records in rowid order. Not guaranteed to be
+  set for unordered (e.g. HASH) indexes.
+*/
+#define HA_KEY_SCAN_NOT_ROR     128 
+#define HA_DO_INDEX_COND_PUSHDOWN  256 /* Supports Index Condition Pushdown */
+
+
+
+/*
+  HA_PARTITION_FUNCTION_SUPPORTED indicates that the function is
+  supported at all.
+  HA_FAST_CHANGE_PARTITION means that optimised variants of the changes
+  exists but they are not necessarily done online.
+
+  HA_ONLINE_DOUBLE_WRITE means that the handler supports writing to both
+  the new partition and to the old partitions when updating through the
+  old partitioning schema while performing a change of the partitioning.
+  This means that we can support updating of the table while performing
+  the copy phase of the change. For no lock at all also a double write
+  from new to old must exist and this is not required when this flag is
+  set.
+  This is actually removed even before it was introduced the first time.
+  The new idea is that handlers will handle the lock level already in
+  store_lock for ALTER Table partitions.
+
+  HA_PARTITION_ONE_PHASE is a flag that can be set by handlers that take
+  care of changing the partitions online and in one phase. Thus all phases
+  needed to handle the change are implemented inside the storage engine.
+  The storage engine must also support auto-discovery since the frm file
+  is changed as part of the change and this change must be controlled by
+  the storage engine. A typical engine to support this is NDB (through
+  WL #2498).
+*/
+#define HA_PARTITION_FUNCTION_SUPPORTED         (1L << 1)
+#define HA_FAST_CHANGE_PARTITION                (1L << 2)
+#define HA_PARTITION_ONE_PHASE                  (1L << 3)
+
+/* operations for disable/enable indexes */
+#define HA_KEY_SWITCH_NONUNIQ      0
+#define HA_KEY_SWITCH_ALL          1
+#define HA_KEY_SWITCH_NONUNIQ_SAVE 2
+#define HA_KEY_SWITCH_ALL_SAVE     3
+
+/*
+  Note: the following includes binlog and closing 0.
+  so: innodb + bdb + ndb + binlog + myisam + myisammrg + archive +
+      example + csv + heap + blackhole + federated + 0
+  (yes, the sum is deliberately inaccurate)
+  TODO remove the limit, use dynarrays
+*/
+#define MAX_HA 15
+
+/*
+  Parameters for open() (in register form->filestat)
+  HA_GET_INFO does an implicit HA_ABORT_IF_LOCKED
+*/
+
+#define HA_OPEN_KEYFILE		1
+#define HA_OPEN_RNDFILE		2
+#define HA_GET_INDEX		4
+#define HA_GET_INFO		8	/* do a ha_info() after open */
+#define HA_READ_ONLY		16	/* File opened as readonly */
+/* Try readonly if can't open with read and write */
+#define HA_TRY_READ_ONLY	32
+#define HA_WAIT_IF_LOCKED	64	/* Wait if locked on open */
+#define HA_ABORT_IF_LOCKED	128	/* skip if locked on open.*/
+#define HA_BLOCK_LOCK		256	/* unlock when reading some records */
+#define HA_OPEN_TEMPORARY	512
+
+/* For transactional LOCK Table. handler::lock_table() */
+#define HA_LOCK_IN_SHARE_MODE      F_RDLCK
+#define HA_LOCK_IN_EXCLUSIVE_MODE  F_WRLCK
+
+/* Some key definitions */
+#define HA_KEY_NULL_LENGTH	1
+#define HA_KEY_BLOB_LENGTH	2
+
+#define HA_LEX_CREATE_TMP_TABLE	1
+#define HA_LEX_CREATE_IF_NOT_EXISTS 2
+#define HA_LEX_CREATE_TABLE_LIKE 4
+#define HA_OPTION_NO_CHECKSUM	(1L << 17)
+#define HA_OPTION_NO_DELAY_KEY_WRITE (1L << 18)
+#define HA_MAX_REC_LENGTH	65535
+
+/* Table caching type */
+#define HA_CACHE_TBL_NONTRANSACT 0
+#define HA_CACHE_TBL_NOCACHE     1
+#define HA_CACHE_TBL_ASKTRANSACT 2
+#define HA_CACHE_TBL_TRANSACT    4
+
+/* Options of START TRANSACTION statement (and later of SET TRANSACTION stmt) */
+#define DRIZZLE_START_TRANS_OPT_WITH_CONS_SNAPSHOT 1
+
+/* Flags for method is_fatal_error */
+#define HA_CHECK_DUP_KEY 1
+#define HA_CHECK_DUP_UNIQUE 2
+#define HA_CHECK_DUP (HA_CHECK_DUP_KEY + HA_CHECK_DUP_UNIQUE)
+
+enum legacy_db_type
+{
+  DB_TYPE_UNKNOWN=0,
+  DB_TYPE_FIRST_DYNAMIC=42,
+  DB_TYPE_DEFAULT=127 // Must be last
+};
+
+enum row_type { ROW_TYPE_NOT_USED=-1, ROW_TYPE_DEFAULT, ROW_TYPE_FIXED,
+		ROW_TYPE_DYNAMIC, ROW_TYPE_COMPRESSED,
+		ROW_TYPE_REDUNDANT, ROW_TYPE_COMPACT, ROW_TYPE_PAGE };
+
+enum column_format_type { COLUMN_FORMAT_TYPE_NOT_USED= -1,
+                          COLUMN_FORMAT_TYPE_DEFAULT=   0,
+                          COLUMN_FORMAT_TYPE_FIXED=     1,
+                          COLUMN_FORMAT_TYPE_DYNAMIC=   2 };
+
+enum enum_binlog_func {
+  BFN_RESET_LOGS=        1,
+  BFN_RESET_SLAVE=       2,
+  BFN_BINLOG_WAIT=       3,
+  BFN_BINLOG_END=        4,
+  BFN_BINLOG_PURGE_FILE= 5
+};
+
+enum enum_binlog_command {
+  LOGCOM_CREATE_TABLE,
+  LOGCOM_ALTER_TABLE,
+  LOGCOM_RENAME_TABLE,
+  LOGCOM_DROP_TABLE,
+  LOGCOM_CREATE_DB,
+  LOGCOM_ALTER_DB,
+  LOGCOM_DROP_DB
+};
+
+/* struct to hold information about the table that should be created */
+
+/* Bits in used_fields */
+#define HA_CREATE_USED_AUTO             (1L << 0)
+#ifdef DEAD_OPTIONS
+#define HA_CREATE_USED_UNION            (1L << 2)
+#define HA_CREATE_USED_PASSWORD         (1L << 17)
+#endif
+#define HA_CREATE_USED_INSERT_METHOD    (1L << 3)
+#define HA_CREATE_USED_MIN_ROWS         (1L << 4)
+#define HA_CREATE_USED_MAX_ROWS         (1L << 5)
+#define HA_CREATE_USED_AVG_ROW_LENGTH   (1L << 6)
+#define HA_CREATE_USED_PACK_KEYS        (1L << 7)
+#define HA_CREATE_USED_CHARSET          (1L << 8)
+#define HA_CREATE_USED_DEFAULT_CHARSET  (1L << 9)
+#define HA_CREATE_USED_DATADIR          (1L << 10)
+#define HA_CREATE_USED_INDEXDIR         (1L << 11)
+#define HA_CREATE_USED_ENGINE           (1L << 12)
+#define HA_CREATE_USED_CHECKSUM         (1L << 13)
+#define HA_CREATE_USED_DELAY_KEY_WRITE  (1L << 14)
+#define HA_CREATE_USED_ROW_FORMAT       (1L << 15)
+#define HA_CREATE_USED_COMMENT          (1L << 16)
+#define HA_CREATE_USED_CONNECTION       (1L << 18)
+#define HA_CREATE_USED_KEY_BLOCK_SIZE   (1L << 19)
+#define HA_CREATE_USED_PAGE_CHECKSUM    (1L << 21)
+#define HA_CREATE_USED_BLOCK_SIZE       (1L << 22)
+
+#define MAXGTRIDSIZE 64
+#define MAXBQUALSIZE 64
+
+#define COMPATIBLE_DATA_YES 0
+#define COMPATIBLE_DATA_NO  1
+
+#define UNDEF_NODEGROUP 65535
+#define NOT_A_PARTITION_ID ((uint32_t)-1)
+
+enum ha_choice { HA_CHOICE_UNDEF, HA_CHOICE_NO, HA_CHOICE_YES };
+
+/* Possible flags of a handlerton (there can be 32 of them) */
+#define HTON_NO_FLAGS                 0
+#define HTON_CLOSE_CURSORS_AT_COMMIT (1 << 0)
+#define HTON_ALTER_NOT_SUPPORTED     (1 << 1) //Engine does not support alter
+#define HTON_CAN_RECREATE            (1 << 2) //Delete all is used fro truncate
+#define HTON_HIDDEN                  (1 << 3) //Engine does not appear in lists
+#define HTON_FLUSH_AFTER_RENAME      (1 << 4)
+#define HTON_NOT_USER_SELECTABLE     (1 << 5)
+#define HTON_TEMPORARY_NOT_SUPPORTED (1 << 6) //Having temporary tables not supported
+#define HTON_SUPPORT_LOG_TABLES      (1 << 7) //Engine supports log tables
+#define HTON_NO_PARTITION            (1 << 8) //You can not partition these tables
+/*
+  The below two are not used (and not handled) in this milestone of this WL
+  entry because there seems to be no use for them at this stage of
+  implementation.
+*/
+#define HA_MRR_SINGLE_POINT 1
+#define HA_MRR_FIXED_KEY  2
+
+/* 
+  Indicates that RANGE_SEQ_IF::next(&range) doesn't need to fill in the
+  'range' parameter.
+*/
+#define HA_MRR_NO_ASSOCIATION 4
+
+/* 
+  The MRR user will provide ranges in key order, and MRR implementation
+  must return rows in key order.
+*/
+#define HA_MRR_SORTED 8
+
+/* MRR implementation doesn't have to retrieve full records */
+#define HA_MRR_INDEX_ONLY 16
+
+/* 
+  The passed memory buffer is of maximum possible size, the caller can't
+  assume larger buffer.
+*/
+#define HA_MRR_LIMITS 32
+
+
+/*
+  Flag set <=> default MRR implementation is used
+  (The choice is made by **_info[_const]() function which may set this
+   flag. SQL layer remembers the flag value and then passes it to
+   multi_read_range_init().
+*/
+#define HA_MRR_USE_DEFAULT_IMPL 64
+
+/*
+  Used only as parameter to multi_range_read_info():
+  Flag set <=> the caller guarantees that the bounds of the scanned ranges
+  will not have NULL values.
+*/
+#define HA_MRR_NO_NULL_ENDPOINTS 128
+
 #endif /* DRIZZLE_SERVER_DEFINITIONS_H */

=== modified file 'drizzled/field_iterator.h'
--- drizzled/field_iterator.h	2008-10-20 04:28:21 +0000
+++ drizzled/field_iterator.h	2008-10-30 19:42:06 +0000
@@ -21,6 +21,9 @@
 #ifndef DRIZZLED_FIELD_ITERATOR_H
 #define DRIZZLED_FIELD_ITERATOR_H
 
+#include <drizzled/sql_alloc.h>
+#include <drizzled/sql_list.h>
+
 class Table;
 class TableList;
 

=== modified file 'drizzled/handler.h'
--- drizzled/handler.h	2008-10-30 19:22:40 +0000
+++ drizzled/handler.h	2008-10-30 19:42:06 +0000
@@ -36,320 +36,6 @@
 #define HA_MAX_ALTER_FLAGS 40
 typedef Bitmap<HA_MAX_ALTER_FLAGS> HA_ALTER_FLAGS;
 
-#ifndef NO_HASH
-#define NO_HASH				/* Not yet implemented */
-#endif
-
-// the following is for checking tables
-
-#define HA_ADMIN_ALREADY_DONE	  1
-#define HA_ADMIN_OK               0
-#define HA_ADMIN_NOT_IMPLEMENTED -1
-#define HA_ADMIN_FAILED		 -2
-#define HA_ADMIN_CORRUPT         -3
-#define HA_ADMIN_INTERNAL_ERROR  -4
-#define HA_ADMIN_INVALID         -5
-#define HA_ADMIN_REJECT          -6
-#define HA_ADMIN_TRY_ALTER       -7
-#define HA_ADMIN_WRONG_CHECKSUM  -8
-#define HA_ADMIN_NOT_BASE_TABLE  -9
-#define HA_ADMIN_NEEDS_UPGRADE  -10
-#define HA_ADMIN_NEEDS_ALTER    -11
-#define HA_ADMIN_NEEDS_CHECK    -12
-
-
-#define HA_ADD_INDEX                  (0)
-#define HA_DROP_INDEX                 (1)
-#define HA_ALTER_INDEX                (2)
-#define HA_RENAME_INDEX               (3)
-#define HA_ADD_UNIQUE_INDEX           (4)
-#define HA_DROP_UNIQUE_INDEX          (5)
-#define HA_ALTER_UNIQUE_INDEX         (6)
-#define HA_RENAME_UNIQUE_INDEX        (7)
-#define HA_ADD_PK_INDEX               (8)
-#define HA_DROP_PK_INDEX              (9)
-#define HA_ALTER_PK_INDEX             (10)
-#define HA_ADD_COLUMN                 (11)
-#define HA_DROP_COLUMN                (12)
-#define HA_CHANGE_COLUMN              (13)
-#define HA_ALTER_COLUMN_NAME          (14)
-#define HA_ALTER_COLUMN_TYPE          (15)
-#define HA_ALTER_COLUMN_ORDER         (16)
-#define HA_ALTER_COLUMN_NULLABLE      (17)
-#define HA_COLUMN_DEFAULT_VALUE       (18)
-#define HA_COLUMN_STORAGE             (19)
-#define HA_COLUMN_FORMAT              (20)
-#define HA_ADD_FOREIGN_KEY            (21)
-#define HA_DROP_FOREIGN_KEY           (22)
-#define HA_ALTER_FOREIGN_KEY          (23)
-#define HA_ADD_CONSTRAINT             (24)
-#define HA_CHANGE_CHARACTER_SET       (30)
-#define HA_SET_DEFAULT_CHARACTER_SET  (31)
-#define HA_CHANGE_AUTOINCREMENT_VALUE (32)
-#define HA_ALTER_STORAGE              (33)
-#define HA_ALTER_TABLESPACE           (34)
-#define HA_ALTER_ROW_FORMAT           (35)
-#define HA_RENAME_TABLE               (36)
-#define HA_ALTER_STORAGE_ENGINE       (37)
-#define HA_RECREATE                   (38)
-#define HA_ALTER_STORED_VCOL          (39)
-/* Remember to increase HA_MAX_ALTER_FLAGS when adding more flags! */
-
-/* Return values for check_if_supported_alter */
-
-#define HA_ALTER_ERROR               -1
-#define HA_ALTER_SUPPORTED_WAIT_LOCK  0
-#define HA_ALTER_SUPPORTED_NO_LOCK    1
-#define HA_ALTER_NOT_SUPPORTED        2
-
-/* Bits in table_flags() to show what database can do */
-
-#define HA_NO_TRANSACTIONS     (1 << 0) /* Doesn't support transactions */
-#define HA_PARTIAL_COLUMN_READ (1 << 1) /* read may not return all columns */
-#define HA_TABLE_SCAN_ON_INDEX (1 << 2) /* No separate data/index file */
-/*
-  The following should be set if the following is not true when scanning
-  a table with rnd_next()
-  - We will see all rows (including deleted ones)
-  - Row positions are 'table->s->db_record_offset' apart
-  If this flag is not set, filesort will do a postion() call for each matched
-  row to be able to find the row later.
-*/
-#define HA_REC_NOT_IN_SEQ      (1 << 3)
-
-/*
-  Reading keys in random order is as fast as reading keys in sort order
-  (Used in records.cc to decide if we should use a record cache and by
-  filesort to decide if we should sort key + data or key + pointer-to-row
-*/
-#define HA_FAST_KEY_READ       (1 << 5)
-/*
-  Set the following flag if we on delete should force all key to be read
-  and on update read all keys that changes
-*/
-#define HA_REQUIRES_KEY_COLUMNS_FOR_DELETE (1 << 6)
-#define HA_NULL_IN_KEY         (1 << 7) /* One can have keys with NULL */
-#define HA_DUPLICATE_POS       (1 << 8)    /* ha_position() gives dup row */
-#define HA_NO_BLOBS            (1 << 9) /* Doesn't support blobs */
-#define HA_CAN_INDEX_BLOBS     (1 << 10)
-#define HA_AUTO_PART_KEY       (1 << 11) /* auto-increment in multi-part key */
-#define HA_REQUIRE_PRIMARY_KEY (1 << 12) /* .. and can't create a hidden one */
-#define HA_STATS_RECORDS_IS_EXACT (1 << 13) /* stats.records is exact */
-/*
-  If we get the primary key columns for free when we do an index read
-  It also implies that we have to retrive the primary key when using
-  position() and rnd_pos().
-*/
-#define HA_PRIMARY_KEY_IN_READ_INDEX (1 << 15)
-/*
-  If HA_PRIMARY_KEY_REQUIRED_FOR_POSITION is set, it means that to position()
-  uses a primary key. Without primary key, we can't call position().
-*/ 
-#define HA_PRIMARY_KEY_REQUIRED_FOR_POSITION (1 << 16) 
-#define HA_NOT_DELETE_WITH_CACHE (1 << 18)
-/*
-  The following is we need to a primary key to delete (and update) a row.
-  If there is no primary key, all columns needs to be read on update and delete
-*/
-#define HA_PRIMARY_KEY_REQUIRED_FOR_DELETE (1 << 19)
-#define HA_NO_PREFIX_CHAR_KEYS (1 << 20)
-#define HA_NO_AUTO_INCREMENT   (1 << 23)
-#define HA_HAS_CHECKSUM        (1 << 24)
-/* Table data are stored in separate files (for lower_case_table_names) */
-#define HA_FILE_BASED	       (1 << 26)
-#define HA_NEED_READ_RANGE_BUFFER (1 << 29) /* for read_multi_range */
-#define HA_ANY_INDEX_MAY_BE_UNIQUE (1 << 30)
-#define HA_NO_COPY_ON_ALTER    (INT64_C(1) << 31)
-#define HA_HAS_RECORDS	       (INT64_C(1) << 32) /* records() gives exact count*/
-#define HA_MRR_CANT_SORT       (INT64_C(1) << 34)
-
-/*
-  Engine is capable of row-format and statement-format logging,
-  respectively
-*/
-#define HA_BINLOG_ROW_CAPABLE  (INT64_C(1) << 35)
-#define HA_BINLOG_STMT_CAPABLE (INT64_C(1) << 36)
-
-#define HA_ONLINE_ALTER        (INT64_C(1) << 37)
-
-/*
-  Set of all binlog flags. Currently only contain the capabilities
-  flags.
- */
-#define HA_BINLOG_FLAGS (HA_BINLOG_ROW_CAPABLE | HA_BINLOG_STMT_CAPABLE)
-
-/* bits in index_flags(index_number) for what you can do with index */
-#define HA_READ_NEXT            1       /* TODO really use this flag */
-#define HA_READ_PREV            2       /* supports ::index_prev */
-#define HA_READ_ORDER           4       /* index_next/prev follow sort order */
-#define HA_READ_RANGE           8       /* can find all records in a range */
-#define HA_ONLY_WHOLE_INDEX	16	/* Can't use part key searches */
-#define HA_KEYREAD_ONLY         64	/* Support HA_EXTRA_KEYREAD */
-/*
-  Index scan will not return records in rowid order. Not guaranteed to be
-  set for unordered (e.g. HASH) indexes.
-*/
-#define HA_KEY_SCAN_NOT_ROR     128 
-#define HA_DO_INDEX_COND_PUSHDOWN  256 /* Supports Index Condition Pushdown */
-
-
-
-/*
-  HA_PARTITION_FUNCTION_SUPPORTED indicates that the function is
-  supported at all.
-  HA_FAST_CHANGE_PARTITION means that optimised variants of the changes
-  exists but they are not necessarily done online.
-
-  HA_ONLINE_DOUBLE_WRITE means that the handler supports writing to both
-  the new partition and to the old partitions when updating through the
-  old partitioning schema while performing a change of the partitioning.
-  This means that we can support updating of the table while performing
-  the copy phase of the change. For no lock at all also a double write
-  from new to old must exist and this is not required when this flag is
-  set.
-  This is actually removed even before it was introduced the first time.
-  The new idea is that handlers will handle the lock level already in
-  store_lock for ALTER Table partitions.
-
-  HA_PARTITION_ONE_PHASE is a flag that can be set by handlers that take
-  care of changing the partitions online and in one phase. Thus all phases
-  needed to handle the change are implemented inside the storage engine.
-  The storage engine must also support auto-discovery since the frm file
-  is changed as part of the change and this change must be controlled by
-  the storage engine. A typical engine to support this is NDB (through
-  WL #2498).
-*/
-#define HA_PARTITION_FUNCTION_SUPPORTED         (1L << 1)
-#define HA_FAST_CHANGE_PARTITION                (1L << 2)
-#define HA_PARTITION_ONE_PHASE                  (1L << 3)
-
-/* operations for disable/enable indexes */
-#define HA_KEY_SWITCH_NONUNIQ      0
-#define HA_KEY_SWITCH_ALL          1
-#define HA_KEY_SWITCH_NONUNIQ_SAVE 2
-#define HA_KEY_SWITCH_ALL_SAVE     3
-
-/*
-  Note: the following includes binlog and closing 0.
-  so: innodb + bdb + ndb + binlog + myisam + myisammrg + archive +
-      example + csv + heap + blackhole + federated + 0
-  (yes, the sum is deliberately inaccurate)
-  TODO remove the limit, use dynarrays
-*/
-#define MAX_HA 15
-
-/*
-  Parameters for open() (in register form->filestat)
-  HA_GET_INFO does an implicit HA_ABORT_IF_LOCKED
-*/
-
-#define HA_OPEN_KEYFILE		1
-#define HA_OPEN_RNDFILE		2
-#define HA_GET_INDEX		4
-#define HA_GET_INFO		8	/* do a ha_info() after open */
-#define HA_READ_ONLY		16	/* File opened as readonly */
-/* Try readonly if can't open with read and write */
-#define HA_TRY_READ_ONLY	32
-#define HA_WAIT_IF_LOCKED	64	/* Wait if locked on open */
-#define HA_ABORT_IF_LOCKED	128	/* skip if locked on open.*/
-#define HA_BLOCK_LOCK		256	/* unlock when reading some records */
-#define HA_OPEN_TEMPORARY	512
-
-/* For transactional LOCK Table. handler::lock_table() */
-#define HA_LOCK_IN_SHARE_MODE      F_RDLCK
-#define HA_LOCK_IN_EXCLUSIVE_MODE  F_WRLCK
-
-/* Some key definitions */
-#define HA_KEY_NULL_LENGTH	1
-#define HA_KEY_BLOB_LENGTH	2
-
-#define HA_LEX_CREATE_TMP_TABLE	1
-#define HA_LEX_CREATE_IF_NOT_EXISTS 2
-#define HA_LEX_CREATE_TABLE_LIKE 4
-#define HA_OPTION_NO_CHECKSUM	(1L << 17)
-#define HA_OPTION_NO_DELAY_KEY_WRITE (1L << 18)
-#define HA_MAX_REC_LENGTH	65535
-
-/* Table caching type */
-#define HA_CACHE_TBL_NONTRANSACT 0
-#define HA_CACHE_TBL_NOCACHE     1
-#define HA_CACHE_TBL_ASKTRANSACT 2
-#define HA_CACHE_TBL_TRANSACT    4
-
-/* Options of START TRANSACTION statement (and later of SET TRANSACTION stmt) */
-#define DRIZZLE_START_TRANS_OPT_WITH_CONS_SNAPSHOT 1
-
-/* Flags for method is_fatal_error */
-#define HA_CHECK_DUP_KEY 1
-#define HA_CHECK_DUP_UNIQUE 2
-#define HA_CHECK_DUP (HA_CHECK_DUP_KEY + HA_CHECK_DUP_UNIQUE)
-
-enum legacy_db_type
-{
-  DB_TYPE_UNKNOWN=0,
-  DB_TYPE_FIRST_DYNAMIC=42,
-  DB_TYPE_DEFAULT=127 // Must be last
-};
-
-enum row_type { ROW_TYPE_NOT_USED=-1, ROW_TYPE_DEFAULT, ROW_TYPE_FIXED,
-		ROW_TYPE_DYNAMIC, ROW_TYPE_COMPRESSED,
-		ROW_TYPE_REDUNDANT, ROW_TYPE_COMPACT, ROW_TYPE_PAGE };
-
-enum column_format_type { COLUMN_FORMAT_TYPE_NOT_USED= -1,
-                          COLUMN_FORMAT_TYPE_DEFAULT=   0,
-                          COLUMN_FORMAT_TYPE_FIXED=     1,
-                          COLUMN_FORMAT_TYPE_DYNAMIC=   2 };
-
-enum enum_binlog_func {
-  BFN_RESET_LOGS=        1,
-  BFN_RESET_SLAVE=       2,
-  BFN_BINLOG_WAIT=       3,
-  BFN_BINLOG_END=        4,
-  BFN_BINLOG_PURGE_FILE= 5
-};
-
-enum enum_binlog_command {
-  LOGCOM_CREATE_TABLE,
-  LOGCOM_ALTER_TABLE,
-  LOGCOM_RENAME_TABLE,
-  LOGCOM_DROP_TABLE,
-  LOGCOM_CREATE_DB,
-  LOGCOM_ALTER_DB,
-  LOGCOM_DROP_DB
-};
-
-/* struct to hold information about the table that should be created */
-
-/* Bits in used_fields */
-#define HA_CREATE_USED_AUTO             (1L << 0)
-#ifdef DEAD_OPTIONS
-#define HA_CREATE_USED_UNION            (1L << 2)
-#define HA_CREATE_USED_PASSWORD         (1L << 17)
-#endif
-#define HA_CREATE_USED_INSERT_METHOD    (1L << 3)
-#define HA_CREATE_USED_MIN_ROWS         (1L << 4)
-#define HA_CREATE_USED_MAX_ROWS         (1L << 5)
-#define HA_CREATE_USED_AVG_ROW_LENGTH   (1L << 6)
-#define HA_CREATE_USED_PACK_KEYS        (1L << 7)
-#define HA_CREATE_USED_CHARSET          (1L << 8)
-#define HA_CREATE_USED_DEFAULT_CHARSET  (1L << 9)
-#define HA_CREATE_USED_DATADIR          (1L << 10)
-#define HA_CREATE_USED_INDEXDIR         (1L << 11)
-#define HA_CREATE_USED_ENGINE           (1L << 12)
-#define HA_CREATE_USED_CHECKSUM         (1L << 13)
-#define HA_CREATE_USED_DELAY_KEY_WRITE  (1L << 14)
-#define HA_CREATE_USED_ROW_FORMAT       (1L << 15)
-#define HA_CREATE_USED_COMMENT          (1L << 16)
-#define HA_CREATE_USED_CONNECTION       (1L << 18)
-#define HA_CREATE_USED_KEY_BLOCK_SIZE   (1L << 19)
-#define HA_CREATE_USED_PAGE_CHECKSUM    (1L << 21)
-#define HA_CREATE_USED_BLOCK_SIZE       (1L << 22)
-
-#define MAXGTRIDSIZE 64
-#define MAXBQUALSIZE 64
-
-#define COMPATIBLE_DATA_YES 0
-#define COMPATIBLE_DATA_NO  1
 
 typedef bool (*qc_engine_callback)(Session *session, char *table_key,
                                       uint32_t key_length,
@@ -472,17 +158,6 @@
 };
 
 
-/* Possible flags of a handlerton (there can be 32 of them) */
-#define HTON_NO_FLAGS                 0
-#define HTON_CLOSE_CURSORS_AT_COMMIT (1 << 0)
-#define HTON_ALTER_NOT_SUPPORTED     (1 << 1) //Engine does not support alter
-#define HTON_CAN_RECREATE            (1 << 2) //Delete all is used fro truncate
-#define HTON_HIDDEN                  (1 << 3) //Engine does not appear in lists
-#define HTON_FLUSH_AFTER_RENAME      (1 << 4)
-#define HTON_NOT_USER_SELECTABLE     (1 << 5)
-#define HTON_TEMPORARY_NOT_SUPPORTED (1 << 6) //Having temporary tables not supported
-#define HTON_SUPPORT_LOG_TABLES      (1 << 7) //Engine supports log tables
-#define HTON_NO_PARTITION            (1 << 8) //You can not partition these tables
 
 class Ha_trx_info;
 
@@ -638,13 +313,9 @@
   uint64_t check_sum;
 } PARTITION_INFO;
 
-#define UNDEF_NODEGROUP 65535
 class Item;
 struct st_table_log_memory_entry;
 
-#define NOT_A_PARTITION_ID ((uint32_t)-1)
-
-enum ha_choice { HA_CHOICE_UNDEF, HA_CHOICE_NO, HA_CHOICE_YES };
 
 typedef struct st_ha_create_information
 {
@@ -872,50 +543,6 @@
 void get_sweep_read_cost(Table *table, ha_rows nrows, bool interrupted, 
                          COST_VECT *cost);
 
-/*
-  The below two are not used (and not handled) in this milestone of this WL
-  entry because there seems to be no use for them at this stage of
-  implementation.
-*/
-#define HA_MRR_SINGLE_POINT 1
-#define HA_MRR_FIXED_KEY  2
-
-/* 
-  Indicates that RANGE_SEQ_IF::next(&range) doesn't need to fill in the
-  'range' parameter.
-*/
-#define HA_MRR_NO_ASSOCIATION 4
-
-/* 
-  The MRR user will provide ranges in key order, and MRR implementation
-  must return rows in key order.
-*/
-#define HA_MRR_SORTED 8
-
-/* MRR implementation doesn't have to retrieve full records */
-#define HA_MRR_INDEX_ONLY 16
-
-/* 
-  The passed memory buffer is of maximum possible size, the caller can't
-  assume larger buffer.
-*/
-#define HA_MRR_LIMITS 32
-
-
-/*
-  Flag set <=> default MRR implementation is used
-  (The choice is made by **_info[_const]() function which may set this
-   flag. SQL layer remembers the flag value and then passes it to
-   multi_read_range_init().
-*/
-#define HA_MRR_USE_DEFAULT_IMPL 64
-
-/*
-  Used only as parameter to multi_range_read_info():
-  Flag set <=> the caller guarantees that the bounds of the scanned ranges
-  will not have NULL values.
-*/
-#define HA_MRR_NO_NULL_ENDPOINTS 128
 
 
 class ha_statistics

=== modified file 'drizzled/natural_join_column.h'
--- drizzled/natural_join_column.h	2008-10-20 04:28:21 +0000
+++ drizzled/natural_join_column.h	2008-10-30 19:42:06 +0000
@@ -20,8 +20,11 @@
 #ifndef DRIZZLED_NATURAL_JOIN_COLUMN_H
 #define DRIZZLED_NATURAL_JOIN_COLUMN_H
 
+#include <drizzled/sql_alloc.h>
+
 class Field;
 class Field_translator;
+class TableList;
 
 /*
   Column reference of a NATURAL/USING join. Since column references in

=== modified file 'drizzled/order.h'
--- drizzled/order.h	2008-09-16 00:00:48 +0000
+++ drizzled/order.h	2008-10-30 19:42:06 +0000
@@ -20,6 +20,8 @@
 #ifndef DRIZZLED_ORDER_H
 #define DRIZZLED_ORDER_H
 
+#include <drizzled/sql_bitmap.h>
+
 /* Order clause list element */
 
 struct order_st {

=== modified file 'drizzled/sql_alloc.h'
--- drizzled/sql_alloc.h	2008-10-20 04:28:21 +0000
+++ drizzled/sql_alloc.h	2008-10-30 19:42:06 +0000
@@ -22,6 +22,7 @@
 
 #include <libdrizzle/net_serv.h>
 
+
 void init_sql_alloc(MEM_ROOT *root, uint32_t block_size, uint32_t pre_alloc_size);
 void *sql_alloc(size_t);
 void *sql_calloc(size_t);
@@ -38,4 +39,43 @@
 bool net_request_file(NET* net, const char* fname);
 char* query_table_status(Session *session,const char *db,const char *table_name);
 
+/* mysql standard class memory allocator */
+class Sql_alloc
+{
+public:
+  static void *operator new(size_t size) throw ()
+  {
+    return sql_alloc(size);
+  }
+  static void *operator new[](size_t size)
+  {
+    return sql_alloc(size);
+  }
+  static void *operator new[](size_t size, MEM_ROOT *mem_root) throw ()
+  { return alloc_root(mem_root, size); }
+  static void *operator new(size_t size, MEM_ROOT *mem_root) throw ()
+  { return alloc_root(mem_root, size); }
+  static void operator delete(void *ptr __attribute__((unused)),
+                              size_t size __attribute__((unused)))
+  { TRASH(ptr, size); }
+  static void operator delete(void *ptr __attribute__((unused)),
+                              MEM_ROOT *mem_root __attribute__((unused)))
+  { /* never called */ }
+  static void operator delete[](void *ptr __attribute__((unused)),
+                                MEM_ROOT *mem_root __attribute__((unused)))
+  { /* never called */ }
+  static void operator delete[](void *ptr __attribute__((unused)),
+                                size_t size __attribute__((unused)))
+  { TRASH(ptr, size); }
+#ifdef HAVE_purify
+  bool dummy;
+  inline Sql_alloc() :dummy(0) {}
+  inline ~Sql_alloc() {}
+#else
+  inline Sql_alloc() {}
+  inline ~Sql_alloc() {}
+#endif
+
+};
+
 #endif /* DRIZZLE_SERVER_SQL_ALLOC_H */

=== modified file 'drizzled/sql_list.h'
--- drizzled/sql_list.h	2008-10-29 18:01:07 +0000
+++ drizzled/sql_list.h	2008-10-30 19:42:06 +0000
@@ -67,46 +67,6 @@
   }
 } SQL_LIST;
 
-/* mysql standard class memory allocator */
-class Sql_alloc
-{
-public:
-  static void *operator new(size_t size) throw ()
-  {
-    return sql_alloc(size);
-  }
-  static void *operator new[](size_t size)
-  {
-    return sql_alloc(size);
-  }
-  static void *operator new[](size_t size, MEM_ROOT *mem_root) throw ()
-  { return alloc_root(mem_root, size); }
-  static void *operator new(size_t size, MEM_ROOT *mem_root) throw ()
-  { return alloc_root(mem_root, size); }
-  static void operator delete(void *ptr __attribute__((unused)),
-                              size_t size __attribute__((unused)))
-  { TRASH(ptr, size); }
-  static void operator delete(void *ptr __attribute__((unused)),
-                              MEM_ROOT *mem_root __attribute__((unused)))
-  { /* never called */ }
-  static void operator delete[](void *ptr __attribute__((unused)),
-                                MEM_ROOT *mem_root __attribute__((unused)))
-  { /* never called */ }
-  static void operator delete[](void *ptr __attribute__((unused)),
-                                size_t size __attribute__((unused)))
-  { TRASH(ptr, size); }
-#ifdef HAVE_purify
-  bool dummy;
-  inline Sql_alloc() :dummy(0) {}
-  inline ~Sql_alloc() {}
-#else
-  inline Sql_alloc() {}
-  inline ~Sql_alloc() {}
-#endif
-
-};
-
-
 /*
   Basic single linked list
   Used for item and item_buffs.

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2008-10-23 23:53:49 +0000
+++ drizzled/table.h	2008-10-30 19:42:06 +0000
@@ -28,6 +28,8 @@
 #include <drizzled/filesort_info.h>
 #include <drizzled/natural_join_column.h>
 #include <drizzled/field_iterator.h>
+#include <mysys/hash.h>
+#include <drizzled/handler.h>
 
 class Item;				/* Needed by order_st */
 class Item_subselect;

